
#ifndef OKTETAKASTENCONTROLLERS_EXPORT_H
#define OKTETAKASTENCONTROLLERS_EXPORT_H

#ifdef OKTETAKASTENCONTROLLERS_STATIC_DEFINE
#  define OKTETAKASTENCONTROLLERS_EXPORT
#  define OKTETAKASTENCONTROLLERS_NO_EXPORT
#else
#  ifndef OKTETAKASTENCONTROLLERS_EXPORT
#    ifdef OktetaKastenControllers_EXPORTS
        /* We are building this library */
#      define OKTETAKASTENCONTROLLERS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define OKTETAKASTENCONTROLLERS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef OKTETAKASTENCONTROLLERS_NO_EXPORT
#    define OKTETAKASTENCONTROLLERS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef OKTETAKASTENCONTROLLERS_DEPRECATED
#  define OKTETAKASTENCONTROLLERS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef OKTETAKASTENCONTROLLERS_DEPRECATED_EXPORT
#  define OKTETAKASTENCONTROLLERS_DEPRECATED_EXPORT OKTETAKASTENCONTROLLERS_EXPORT OKTETAKASTENCONTROLLERS_DEPRECATED
#endif

#ifndef OKTETAKASTENCONTROLLERS_DEPRECATED_NO_EXPORT
#  define OKTETAKASTENCONTROLLERS_DEPRECATED_NO_EXPORT OKTETAKASTENCONTROLLERS_NO_EXPORT OKTETAKASTENCONTROLLERS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef OKTETAKASTENCONTROLLERS_NO_DEPRECATED
#    define OKTETAKASTENCONTROLLERS_NO_DEPRECATED
#  endif
#endif

#endif /* OKTETAKASTENCONTROLLERS_EXPORT_H */
