/*
    This file is part of the Okteta Core library, made within the KDE community.

    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef OKTETA_LINE_HPP
#define OKTETA_LINE_HPP

// Qt
#include <QtGlobal>

namespace Okteta {

using Line = qint32;
using LineSize = qint32;

}

#endif
