/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    SPDX-FileCopyrightText: 2006 Friedrich W. H. Kossebau <kossebau@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef KASTEN_FINDDIRECTION_HPP
#define KASTEN_FINDDIRECTION_HPP

namespace Kasten {

enum FindDirection
{
    FindForward = 0,
    FindBackward = 1
};

}

#endif
